Learn R Programming

grafzahl (version 0.0.12)

predict.grafzahl: Prediction from a fine-tuned grafzahl object

Description

Make prediction from a fine-tuned grafzahl object.

Usage

# S3 method for grafzahl
predict(object, newdata, cuda = detect_cuda(), return_raw = FALSE, ...)

Value

a vector of class prediction or a matrix of logits

Arguments

object

an S3 object trained with grafzahl()

newdata

a quanteda::corpus or a character vector of texts on which prediction should be made.

cuda

logical, whether to use CUDA, default to detect_cuda().

return_raw

logical, if TRUE, return a matrix of logits; a vector of class prediction otherwise

...

not used