Create a grafzahl S3 object from the output_dir
hydrate(output_dir, model_type = NULL, regression = FALSE)a grafzahl S3 object with the following items
original function call
input_data for the underlying python function
location of the output model
model type
model name
whether or not it is a regression model
factor levels of y
random seed
metadata about the current session
string, location of the output model. If missing, the model will be stored in a temporary directory. Important: Please note that if this directory exists, it will be overwritten.
a string indicating model_type of the input model. If NULL, it will be inferred from model_name. Supported model types are available in supported_model_types.
logical, if TRUE, the task is regression, classification otherwise.