Make prediction from a fine-tuned grafzahl object.
# S3 method for grafzahl
predict(object, newdata, cuda = detect_cuda(), return_raw = FALSE, ...)a vector of class prediction or a matrix of logits
an S3 object trained with grafzahl()
a quanteda::corpus or a character vector of texts on which prediction should be made.
logical, whether to use CUDA, default to detect_cuda().
logical, if TRUE, return a matrix of logits; a vector of class prediction otherwise
not used