use_nonconda: Set up grafzahl to be used on Google Colab or similar environments
Description
Set up grafzahl to be used on Google Colab or similar environments. This function is also useful if you do not
want to use conda on a local machine, e.g. you have configurateed the required Python package.
logical, whether to install the required Python packages
check
logical, whether to perform a check after the setup. The check displays 1) whether CUDA can be detected, 2) whether
the non-conda mode has been activated, i.e. whether the option 'grafzahl.nonconda' is TRUE.